@@ -1,7 +1,7 @@
 #  Handles.pm
 #    - interface to the handles used by GnuPG::Interface
 #
-#  Copyright (C) 2000 Frank J. Tobin <ftobin@uiuc.edu>
+#  Copyright (C) 2000 Frank J. Tobin <ftobin@cpan.org>
 #
 #  This module is free software; you can redistribute it and/or modify it
 #  under the same terms as Perl itself.
@@ -10,40 +10,57 @@
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #
-#  $Id: Handles.pm,v 1.6 2000/11/21 18:03:39 ftobin Exp $
+#  $Id: Handles.pm,v 1.8 2001/12/09 02:24:10 ftobin Exp $
 #
 
-
 package GnuPG::Handles;
+use Any::Moose;
+with qw(GnuPG::HashInit);
 
-use strict;
+use constant HANDLES => qw(
+    stdin
+    stdout
+    stderr
+    status
+    logger
+    passphrase
+    command
+);
 
-use constant HANDLES => qw( stdin stdout stderr
-			    status logger passphrase
-			    command
-			  );
+has "$_" => (
+    isa     => 'Any',
+    is      => 'rw',
+    clearer => 'clear_' . $_,
+) for HANDLES;
 
-use Class::MethodMaker
-  get_set       => [ HANDLES ],
-  hash          => [ qw( options ) ],
-  new_with_init => 'new',
-  new_hash_init => 'hash_init';
+has _options => (
+    isa        => 'HashRef',
+    is         => 'rw',
+    lazy_build => 1,
+);
 
+sub options {
+    my $self = shift;
+    my $key = shift;
 
-sub init
-{
-    my ( $self, %args ) = @_;
-    # This is done for the user's convenience so that they don't
-    # have to worry about undefined hashrefs
-    foreach my $handle ( HANDLES ) { $self->options( $handle, {} ) }
-    $self->hash_init( %args );
+    return $self->_options->{$key};
 }
 
+sub _build__options { {} }
 
+sub BUILD {
+    my ( $self, $args ) = @_;
+
+    # This is done for the user's convenience so that they don't
+    # have to worry about undefined hashrefs
+    $self->_options->{$_} = {} for HANDLES;
+    $self->hash_init(%$args);
+}
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
-
 =head1 NAME
 
 GnuPG::Handles - GnuPG handles bundle
@@ -58,7 +75,7 @@ GnuPG::Handles - GnuPG handles bundle
         IO::Handle->new(), IO::Handle->new(), IO::Handle->new(),
       );
  
-  my $handles = GnuPG::Handle->new
+  my $handles = GnuPG::Handles->new
     ( stdin      => $stdin,
       stdout     => $stdout,
       stderr     => $stderr,
@@ -84,23 +101,15 @@ communicate with GnuPG.
 =item new( I<%initialization_args> )
 
 This methods creates a new object.  The optional arguments are
-initialization of data members; the initialization is done
-in a manner according to the method created as described
-in L<Class::MethodMaker/"new_hash_init">.
+initialization of data members.
 
 =item hash_init( I<%args> ).
 
-This method works as described in L<Class::MethodMaker/"new_hash_init">.
 
 =back
 
 =head1 OBJECT DATA MEMBERS
 
-Note that these data members are interacted with via object methods
-created using the methods described in L<Class::MethodMaker/"get_set">,
-or L<Class::MethodMaker/"object">.
-Please read there for more information.
-
 =over 4
 
 =item stdin
@@ -173,6 +182,5 @@ an already-opened file.
 =head1 SEE ALSO
 
 L<GnuPG::Interface>,
-L<Class::MethodMaker>
 
 =cut
