@@ -97,7 +97,7 @@ sub copy {
 
     foreach my $field ( BOOLEANS, SCALARS, LISTS ) {
         my $value = $self->$field();
-        next unless $value;
+        next unless defined $value;
         $new->$field($value);
     }
 
@@ -272,6 +272,8 @@ and then I<extra_args>, in that order.
 
 =item recipients
 
+=back
+
 These options correlate directly to many GnuPG options.  For those that
 are boolean to GnuPG, simply that argument is passed.  For those
 that are associated with a scalar, that scalar is passed passed
@@ -297,6 +299,8 @@ an object shall be prepended with I<_id(s)> if they only
 take an id; otherwise assume an object of type GnuPG::Key
 is required.
 
+=over 4
+
 =item meta_pgp_5_compatible
 
 If true, arguments are generated to try to be compatible with PGP 5.x.
