@@ -1,7 +1,7 @@
 #  SecretKey.pm
 #    - providing an object-oriented approach to GnuPG secret keys
 #
-#  Copyright (C) 2000 Frank J. Tobin <ftobin@uiuc.edu>
+#  Copyright (C) 2000 Frank J. Tobin <ftobin@cpan.org>
 #
 #  This module is free software; you can redistribute it and/or modify it
 #  under the same terms as Perl itself.
@@ -10,16 +10,15 @@
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #
-#  $Id: SecretKey.pm,v 1.7 2001/04/30 00:09:26 ftobin Exp $
+#  $Id: SecretKey.pm,v 1.9 2001/09/14 12:34:36 ftobin Exp $
 #
 
 package GnuPG::SecretKey;
+use Any::Moose;
 
-use strict;
-use GnuPG::PrimaryKey;
+BEGIN { extends qw( GnuPG::PrimaryKey ) }
 
-use vars qw( @ISA );
-push @ISA, 'GnuPG::PrimaryKey';
+__PACKAGE__->meta->make_immutable;
 
 1;
 
